@@ -46,9 +46,11 @@ __all__ = ['amgx',
            'multi_ofed',
            'mvapich2_gdr',
            'mvapich2',
+           'nccl',
            'netcdf',
+           'nsight_compute',
            'nsight_systems',
-           'nv_hpc_sdk',
+           'nvhpc',
            'nvshmem',
            'ofed',
            'openblas',
@@ -59,6 +61,7 @@ __all__ = ['amgx',
            'pmix',
            'pnetcdf',
            'python',
+           'rdma_core',
            'scif',
            'sensei',
            'slurm_pmi2',
@@ -98,9 +101,11 @@ from hpccm.building_blocks.mpich import mpich
 from hpccm.building_blocks.multi_ofed import multi_ofed
 from hpccm.building_blocks.mvapich2_gdr import mvapich2_gdr
 from hpccm.building_blocks.mvapich2 import mvapich2
+from hpccm.building_blocks.nccl import nccl
 from hpccm.building_blocks.netcdf import netcdf
+from hpccm.building_blocks.nsight_compute import nsight_compute
 from hpccm.building_blocks.nsight_systems import nsight_systems
-from hpccm.building_blocks.nv_hpc_sdk import nv_hpc_sdk
+from hpccm.building_blocks.nvhpc import nvhpc
 from hpccm.building_blocks.nvshmem import nvshmem
 from hpccm.building_blocks.ofed import ofed
 from hpccm.building_blocks.openblas import openblas
@@ -111,6 +116,7 @@ from hpccm.building_blocks.pip import pip
 from hpccm.building_blocks.pmix import pmix
 from hpccm.building_blocks.pnetcdf import pnetcdf
 from hpccm.building_blocks.python import python
+from hpccm.building_blocks.rdma_core import rdma_core
 from hpccm.building_blocks.scif import scif
 from hpccm.building_blocks.sensei import sensei
 from hpccm.building_blocks.slurm_pmi2 import slurm_pmi2
