@@ -199,7 +199,7 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
         self.__toolchain = kwargs.get('toolchain', toolchain())
 
         self.__commands = [] # Filled in by __setup()
-        self.__wd = '/var/tmp' # working directory
+        self.__wd = kwargs.get('wd', hpccm.config.g_wd) # working directory
 
         # Construct the series of steps to execute
         self.__setup()
@@ -242,6 +242,10 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
                 self.src_directory = posixpath.join(self.__wd,
                                                     self.__directory)
 
+        # sanity check
+        if not self.src_directory:
+            raise RuntimeError('source directory is not defined')
+
         # Preconfigure setup
         if self.__preconfigure:
             # Assume the preconfigure commands should be run from the
@@ -319,23 +323,20 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
         ```
         """
         if self.prefix:
-            instructions = []
             if self.__comment:
                 if self.url:
-                    instructions.append(comment(self.url, reformat=False))
+                    self.rt += comment(self.url, reformat=False)
                 elif self.repository:
-                    instructions.append(comment(self.repository,
-                                                reformat=False))
-            instructions.append(copy(_from=_from, src=self.prefix,
-                                     dest=self.prefix))
+                    self.rt += comment(self.repository, reformat=False)
+            self.rt += copy(_from=_from, src=self.prefix, dest=self.prefix)
             if self.ldconfig:
-                instructions.append(shell(commands=[self.ldcache_step(
-                    directory=posixpath.join(self.prefix, self.__libdir))]))
+                self.rt += shell(commands=[self.ldcache_step(
+                    directory=posixpath.join(self.prefix, self.__libdir))])
             if self.runtime_environment_variables:
-                instructions.append(environment(
-                    variables=self.environment_step(runtime=True)))
+                self.rt += environment(
+                    variables=self.environment_step(runtime=True))
             if self.annotate:
-                instructions.append(label(metadata=self.annotate_step()))
-            return '\n'.join(str(x) for x in instructions)
+                self.rt += label(metadata=self.annotate_step())
+            return str(self.rt)
         else: # pragma: no cover
             return
