@@ -108,6 +108,8 @@ class generic_build(bb_base, hpccm.templates.annotate,
     values, e.g., `LD_LIBRARY_PATH` and `PATH`, to set in the runtime
     stage.  The default is an empty dictionary.
 
+    unpack: Unpack the sources after downloading. Default is `True`.
+
     url: The URL of the package to build.  One of this parameter or
     the `package` or `repository` or parameters must be specified.
 
@@ -137,9 +139,10 @@ class generic_build(bb_base, hpccm.templates.annotate,
         self.__recursive = kwargs.get('recursive', False)
         self.__run_arguments = kwargs.get('_run_arguments', None)
         self.runtime_environment_variables = kwargs.get('runtime_environment', {})
+        self.__unpack = kwargs.get('unpack', True)
+        self.__wd = kwargs.get('wd', hpccm.config.g_wd) # working directory
 
         self.__commands = [] # Filled in by __setup()
-        self.__wd = '/var/tmp' # working directory
 
         # Construct the series of steps to execute
         self.__setup()
@@ -172,7 +175,7 @@ class generic_build(bb_base, hpccm.templates.annotate,
 
         # Get source
         self.__commands.append(self.download_step(recursive=self.__recursive,
-                                                  wd=self.__wd))
+                                                  wd=self.__wd, unpack=self.__unpack))
 
         # directory containing the unarchived package
         if self.__directory:
@@ -182,6 +185,10 @@ class generic_build(bb_base, hpccm.templates.annotate,
                 self.src_directory = posixpath.join(self.__wd,
                                                     self.__directory)
 
+        # sanity check
+        if not self.src_directory:
+            raise RuntimeError('source directory is not defined')
+
         # Build
         if self.__build:
             self.__commands.append('cd {}'.format(self.src_directory))
@@ -226,22 +233,20 @@ class generic_build(bb_base, hpccm.templates.annotate,
         ```
         """
         if self.__prefix:
-            instructions = []
             if self.__comment:
                 if self.url:
-                    instructions.append(comment(self.url, reformat=False))
+                    self.rt += comment(self.url, reformat=False)
                 elif self.repository:
-                    instructions.append(comment(self.repository, reformat=False))
-            instructions.append(copy(_from=_from, src=self.__prefix,
-                                     dest=self.__prefix))
+                    self.rt += comment(self.repository, reformat=False)
+            self.rt += copy(_from=_from, src=self.__prefix, dest=self.__prefix)
             if self.ldconfig:
-                instructions.append(shell(commands=[self.ldcache_step(
-                    directory=posixpath.join(self.__prefix, self.__libdir))]))
+                self.rt += shell(commands=[self.ldcache_step(
+                    directory=posixpath.join(self.__prefix, self.__libdir))])
             if self.runtime_environment_variables:
-                instructions.append(environment(
-                    variables=self.environment_step(runtime=True)))
+                self.rt += environment(
+                    variables=self.environment_step(runtime=True))
             if self.annotate:
-                instructions.append(label(metadata=self.annotate_step()))
-            return '\n'.join(str(x) for x in instructions)
+                self.rt += label(metadata=self.annotate_step())
+            return str(self.rt)
         else: #pragma: no cover
             return
