@@ -88,7 +88,7 @@ class mlnx_ofed(bb_base, hpccm.templates.annotate, hpccm.templates.rm,
     via the package manager to the standard system locations.
 
     version: The version of Mellanox OFED to download.  The default
-    value is `5.0-2.1.8.0`.
+    value is `5.1-2.3.7.1`.
 
     # Examples
 
@@ -111,7 +111,7 @@ class mlnx_ofed(bb_base, hpccm.templates.annotate, hpccm.templates.rm,
         self.__packages = kwargs.get('packages', [])
         self.__prefix = kwargs.get('prefix', None)
         self.__symlink = kwargs.get('symlink', False)
-        self.__version = kwargs.get('version', '5.0-2.1.8.0')
+        self.__version = kwargs.get('version', '5.1-2.3.7.1')
 
         # Add annotation
         self.add_annotation('version', self.__version)
@@ -238,18 +238,16 @@ class mlnx_ofed(bb_base, hpccm.templates.annotate, hpccm.templates.rm,
         ```
         """
         if self.__prefix:
-            instructions = []
-            instructions.append(comment('Mellanox OFED version {}'.format(
-                self.__version)))
+            self.rt += comment('Mellanox OFED version {}'.format(
+                self.__version))
 
             if self.__deppackages:
-                instructions.append(packages(ospackages=self.__deppackages))
+                self.rt += packages(ospackages=self.__deppackages)
 
             # Suppress warnings from libibverbs
-            instructions.append(shell(commands=['mkdir -p /etc/libibverbs.d']))
+            self.rt += shell(commands=['mkdir -p /etc/libibverbs.d'])
 
-            instructions.append(copy(_from=_from, dest=self.__prefix,
-                                     src=self.__prefix))
-            return '\n'.join(str(x) for x in instructions)
+            self.rt += copy(_from=_from, dest=self.__prefix, src=self.__prefix)
+            return str(self.rt)
         else:
             return str(self)
