@@ -10,7 +10,7 @@ $ hpccm.py --recipe recipes/examples/multistage.py
 
 # Devel stage base image
 Stage0.name = 'devel'
-Stage0.baseimage('nvidia/cuda:9.0-devel-ubuntu16.04')
+Stage0.baseimage('nvcr.io/nvidia/cuda:9.0-devel-ubuntu16.04')
 
 # Install compilers (upstream)
 g = gnu()
@@ -25,7 +25,7 @@ Stage0 += f
 ######
 
 # Runtime stage base image
-Stage1.baseimage('nvidia/cuda:9.0-runtime-ubuntu16.04')
+Stage1.baseimage('nvcr.io/nvidia/cuda:9.0-runtime-ubuntu16.04')
 
 # Compiler runtime (upstream)
 Stage1 += g.runtime()
